@@ -34,7 +34,11 @@ fn code_section_overflow() {
     )
     .unwrap();
     let err = wasmprinter::print_bytes(&bytes).unwrap_err();
-    assert!(err.to_string().contains("Unexpected EOF"), "{:?}", err);
+    assert!(
+        err.to_string().contains("unexpected end-of-file"),
+        "{:?}",
+        err
+    );
 }
 
 #[test]
@@ -114,30 +118,6 @@ fn no_panic_dangling_else() {
     wasmprinter::print_bytes(&bytes).unwrap();
 }
 
-#[test]
-fn module_section_too_large() {
-    let bytes = wat::parse_str(
-        r#"
-            (module binary
-                "\00asm" "\01\00\00\00"     ;; module header
-
-                "\0e"           ;; module section
-                "\08"           ;; size of section
-                "\00"           ;; 0 modules
-                ;; intentionally missing the rest of the section
-            )
-        "#,
-    )
-    .unwrap();
-    let err = wasmprinter::print_bytes(&bytes).unwrap_err();
-    assert!(
-        err.to_string()
-            .contains("unexpected eof reading module section"),
-        "{:?}",
-        err
-    );
-}
-
 #[test]
 fn dangling_if() {
     let bytes = wat::parse_str(
@@ -161,8 +141,31 @@ fn no_oom() {
     for _ in 0..20_000 {
         s.push_str("(func if)\n");
     }
-    s.push_str(")");
+    s.push(')');
     let bytes = wat::parse_str(&s).unwrap();
     let wat = wasmprinter::print_bytes(&bytes).unwrap();
     assert!(wat.len() < 500_000_000);
 }
+
+#[test]
+fn dont_reserve_the_world() {
+    let bytes = wat::parse_str(
+        r#"
+            (module binary
+                "\00asm" "\01\00\00\00"     ;; module header
+
+                "\03"               ;; function section
+                "\05"               ;; section size
+                "\ff\ff\ff\ff\0f"   ;; number of functions (u32::MAX)
+            )
+        "#,
+    )
+    .unwrap();
+    let err = wasmprinter::print_bytes(&bytes).unwrap_err();
+    assert!(
+        err.to_string()
+            .contains("functions which exceeds the limit"),
+        "{:?}",
+        err
+    );
+}
